summaryrefslogtreecommitdiff
path: root/compiler/GHC/Iface/Make.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/Iface/Make.hs')
-rw-r--r--compiler/GHC/Iface/Make.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/compiler/GHC/Iface/Make.hs b/compiler/GHC/Iface/Make.hs
index 5cf6aa5f27..677c8cef71 100644
--- a/compiler/GHC/Iface/Make.hs
+++ b/compiler/GHC/Iface/Make.hs
@@ -38,10 +38,10 @@ import GHC.Core.Coercion.Axiom
import GHC.Core.ConLike
import GHC.Core.DataCon
import GHC.Core.Type
-import TcType
+import GHC.Tc.Utils.TcType
import GHC.Core.InstEnv
import GHC.Core.FamInstEnv
-import TcRnMonad
+import GHC.Tc.Utils.Monad
import GHC.Hs
import GHC.Driver.Types
import GHC.Driver.Session
@@ -218,7 +218,7 @@ mkIface_ hsc_env
not (isWiredInName name),
-- Nor wired-in things; the compiler knows about them anyhow
nameIsLocalOrFrom semantic_mod name ]
- -- Sigh: see Note [Root-main Id] in TcRnDriver
+ -- Sigh: see Note [Root-main Id] in GHC.Tc.Module
-- NB: ABSOLUTELY need to check against semantic_mod,
-- because all of the names in an hsig p[H=<H>]:H
-- are going to be for <H>, not the former id!
@@ -528,7 +528,7 @@ tyConToIfaceDecl env tycon
ifaceConDecls AbstractTyCon = IfAbstractTyCon
-- The AbstractTyCon case happens when a TyCon has been trimmed
-- during tidying.
- -- Furthermore, tyThingToIfaceDecl is also used in TcRnDriver
+ -- Furthermore, tyThingToIfaceDecl is also used in GHC.Tc.Module
-- for GHCi, when browsing a module, in which case the
-- AbstractTyCon and TupleTyCon cases are perfectly sensible.
-- (Tuple declarations are not serialised into interface files.)